Learn R Programming

pmclust (version 0.1-1)

em.onestep.worker: One EM step for workers

Description

One EM step only for model-based clustering of finite mixture Gaussian models with unstructured dispersions. This is a core function of em.step.worker.

Usage

em.onestep.worker(PARAM)

Arguments

PARAM
an original set of parameters generated by set.global.

Value

  • This function is one EM step. The global variables will be updated and a new PARAM will be returned. See the help page of PARAM or PARAM.org for details.

Details

A global variable called X.worker should exist in the .GlobalEnv environment, usually the working environment. The X.worker is the data matrix to be clustered, and this matrix has a dimension N.worker by p.

The PARAM will be a local variable for the current iteration inside em.onestep.worker, and this variable is a list containing all parameters related to models. This function also updates in the parameters by the EM algorithm, and return a new PARAM for the next iteration. The details of list elements are initially generated by set.global.

References

High Performance Statistical Computing Website: http://thirteen-01.stat.iastate.edu/snoweye/hpsc/

See Also

set.global, e.step.worker, m.step.worker.

Examples

Run this code
# This is a core function for em.estep.worker()
# see the source code for details.

Run the code above in your browser using DataLab