Learn R Programming

pmclust (version 0.1-2)

kmeans.update.class.spmd: Update CLASS.spmd Based on the K-Means Final Iteration

Description

Update CLASS.spmd based on the final iteration of K-means algorithms.

Usage

kmeans.update.class.spmd()

Arguments

Value

Details

This function takes Z.spmd from the global environment and update CLASS.spmd, and provides the identification of groups for all data.

References

High Performance Statistical Computing Website: http://thirteen-01.stat.iastate.edu/snoweye/hpsc/

See Also

em.update.class.spmd.

Examples

Run this code
# Examples can be found in the help pages of kmeans.step.spmd().

Run the code above in your browser using DataLab