Learn R Programming

pmclust (version 0.1-1)

kmeans.update.class.worker: Update CLASS.worker based on the K-means final iteration

Description

Update CLASS.worker based on the final iteration of K-means algorithms.

Usage

kmeans.update.class.worker()

Arguments

Value

Details

This function takes Z.worker from the global environment and update CLASS.worker, and provides the identification of groups for all data.

References

High Performance Statistical Computing Website: http://thirteen-01.stat.iastate.edu/snoweye/hpsc/

See Also

em.update.class.worker.

Examples

Run this code
# Examples can be found in the help pages of kmeans.step.worker().

Run the code above in your browser using DataLab