Learn R Programming

pmclust (version 0.1-1)

mb.print: Print results of model-based clustering

Description

This function will print summarized messages for model-based clustering.

Usage

mb.print(PARAM, CHECK)

Arguments

PARAM
a set of convergent parameters to be printed.
CHECK
a set of checking parameters to be printed.

Value

  • Summarized messages will print/cat on screen by default.

Details

This function will provide a quick summary from the PARAM and CHECK typically the output of clusterings when algorithms stop. The COMM.RANK 0 will be used to take care the printing.

References

High Performance Statistical Computing Website: http://thirteen-01.stat.iastate.edu/snoweye/hpsc/

See Also

em.step.worker, aecm.step.worker, apecm1.step.worker, apecm2.step.worker.

Examples

Run this code
# Examples can be found in the help pages of em.step.worker(),
# aecm.step.worker(), apecm1.step.worker(), and apecm2.step.worker().

Run the code above in your browser using DataLab